# tree-sitter-strdl

Tree-sitter parser for Strudel, a Tidal Cycles based live coding tool.

___

## Docs

- [Tree-sitter](https://tree-sitter.github.io/tree-sitter/)
- [Strudel.cc](https://strudel.cc/)
- [Tidal Cycles ](https://tidalcycles.org/)

## Learning Resources

- [Crafting Interpreters by Robert Nystrom](https://www.craftinginterpreters.com/)

